@@ -660,12 +660,11 @@ sub retrieve_assemblies {
 sub restock_assemblies {
   my ($self, $myconfig, $form, $dbh) = @_;
 
-  my $disconnect;
+  my $disconnect = ($dbh) ? 0 : 1;
   
   # connect to database
   if (!$dbh) {
     $dbh = $form->dbconnect_noauto($myconfig);
-    $disconnect = 1;
   }
    
   for my $i (1 .. $form->{rowcount}) {
@@ -1090,7 +1089,7 @@ sub all_parts {
 		    i.trans_id, ct.name, e.name AS employee,
 		    a.curr, a.till, p.notes, p.toolnumber,
 		    p.countryorigin, p.tariff_hscode, p.barcode
-		    $makemodelfld|;
+		    $makemodelflds|;
 
 
       if ($form->{bought}) {
@@ -1165,7 +1164,7 @@ sub all_parts {
 		 i.trans_id, ct.name, e.name AS employee,
 		 a.curr, '0' AS till, p.notes, p.toolnumber,
 		 p.countryorigin, p.tariff_hscode, p.barcode
-		 $makemodelfld|;
+		 $makemodelflds|;
 
       if ($form->{ordered}) {
 	$query .= qq|$union
@@ -1198,7 +1197,7 @@ sub all_parts {
 		   i.trans_id, ct.name, e.name AS employee,
 		   a.curr, '0' AS till, p.notes, p.toolnumber,
 		   p.countryorigin, p.tariff_hscode, p.barcode
-		   $makemodelfld|;
+		   $makemodelflds|;
 		   
 	$query .= qq|$union
 	            SELECT $flds, 'oe' AS module, 'purchase_order' AS type,
@@ -1249,7 +1248,7 @@ sub all_parts {
 		 i.trans_id, ct.name, e.name AS employee,
 		 a.curr, '0' AS till, p.notes, p.toolnumber,
 		 p.countryorigin, p.tariff_hscode, p.barcode
-		 $makemodelfld|;
+		 $makemodelflds|;
 
       if ($form->{quoted}) {
 	$query .= qq|$union
@@ -1282,7 +1281,7 @@ sub all_parts {
 		   i.trans_id, ct.name, e.name AS employee,
 		   a.curr, '0' AS till, p.notes, p.toolnumber,
 		   p.countryorigin, p.tariff_hscode, p.barcode
-		   $makemodelfld|;
+		   $makemodelflds|;
 
 	$query .= qq|$union
 	            SELECT $flds, 'oe' AS module, 'request_quotation' AS type,
@@ -1727,7 +1726,7 @@ sub create_links {
                   l.description AS translation
                   FROM chart c
 		  LEFT JOIN translation l ON (l.trans_id = c.id AND l.language_code = '$myconfig->{countrycode}')
-		  WHERE c.id = $defaults{"${_}_accno_id"}|;
+		  WHERE c.id = '$defaults{"${_}_accno_id"}'|;
       ($form->{"${_}_accno"}, $form->{"${_}_description"}, $form->{"${_}_translation"}) = $dbh->selectrow_array($query);
       $form->{"${_}_description"} = $form->{"${_}_translation"} if $form->{"${_}_translation"};
       $form->{amount}{"IC_$_"} = { accno => $form->{"${_}_accno"}, description => $form->{"${_}_description"} };
