@@ -26,8 +26,7 @@ sub add {
 
   &create_links;
  
-  &form_header;
-  &form_footer;
+  &display_form;
 
 }
 
@@ -38,8 +37,7 @@ sub edit {
 
   &create_links;
   
-  &form_header;
-  &form_footer;
+  &display_form;
  
 }
 
@@ -331,7 +329,11 @@ sub include_in_report {
   push @a, qq|<input name="l_id" type=checkbox class=checkbox value=Y> |.$locale->text('ID');
   push @a, qq|<input name="l_name" type=checkbox class=checkbox value=Y $form->{l_name}> $vcname|;
   push @a, qq|<input name="l_$form->{db}number" type=checkbox class=checkbox value=Y> $vcnumber|;
+  push @a, qq|<input name="l_salutation" type=checkbox class=checkbox value=Y $form->{l_salutation}> |.$locale->text('Salutation');
+  push @a, qq|<input name="l_contacttitle" type=checkbox class=checkbox value=Y $form->{l_contacttitle}> |.$locale->text('Titel');
   push @a, qq|<input name="l_contact" type=checkbox class=checkbox value=Y $form->{l_contact}> |.$locale->text('Contact');
+  push @a, qq|<input name="l_gender" type=checkbox class=checkbox value=Y $form->{l_gender}> |.$locale->text('Gender');
+  push @a, qq|<input name="l_occupation" type=checkbox class=checkbox value=Y $form->{l_occupation}> |.$locale->text('Occupation');
   push @a, qq|<input name="l_email" type=checkbox class=checkbox value=Y $form->{l_email}> |.$locale->text('E-mail');
   push @a, qq|<input name="l_address" type=checkbox class=checkbox value=Y> |.$locale->text('Address');
   push @a, qq|<input name="l_city" type=checkbox class=checkbox value=Y> |.$locale->text('City');
@@ -366,6 +368,7 @@ sub include_in_report {
   }
 
   push @a, qq|<input name="l_sic_code" type=checkbox class=checkbox value=Y> |.$locale->text('SIC');
+  push @a, qq|<input name="l_bank" type=checkbox class=checkbox value=Y> |.$locale->text('Bank');
   push @a, qq|<input name="l_iban" type=checkbox class=checkbox value=Y> |.$locale->text('IBAN');
   push @a, qq|<input name="l_bic" type=checkbox class=checkbox value=Y> |.$locale->text('BIC');
   push @a, qq|<input name="l_business" type=checkbox class=checkbox value=Y> |.$locale->text('Type of Business');
@@ -599,7 +602,19 @@ sub list_names {
   }
   
   @columns = (id, name, "$form->{db}number", address,
-             city, state, zipcode, country, contact,
+             city, state, zipcode, country,
+	     salutation);
+  
+  if ($form->{l_contact}) {
+    for (firstname, lastname) {
+      $form->{"l_$_"} = "Y";
+      push @columns, $_;
+    }
+    $callback .= "&l_contact=Y";
+    $href .= "&l_contact=Y";
+  }
+  
+  push@ columns, (contacttitle, gender, occupation,
 	     phone, fax, email, cc, bcc, employee,
 	     manager, notes, discount, terms, creditlimit);
 
@@ -615,12 +630,17 @@ sub list_names {
   push @columns, (
 	     paymentmethod,
 	     threshold, taxnumber, gifi_accno, sic_code, business,
-	     pricegroup, language, iban, bic, remittancevoucher,
+	     pricegroup, language, bank, iban, bic, remittancevoucher,
 	     startdate, enddate,
 	     invnumber, invamount, invtax, invtotal,
 	     ordnumber, ordamount, ordtax, ordtotal,
 	     quonumber, quoamount, quotax, quototal);
   @columns = $form->sort_columns(@columns);
+  
+  if ($form->{sort} eq 'contact') {
+    grep { s/(firstname|lastname|contact)$// } @columns;
+    unshift @columns, (firstname, lastname);
+  }
   unshift @columns, "ndx";
 
   $form->{l_invnumber} = "Y" if $form->{l_transnumber};
@@ -790,12 +810,17 @@ sub list_names {
   $column_header{state} = qq|<th><a class=listheading href=$href&sort=state>|.$locale->text('State/Province').qq|</a></th>|;
   $column_header{zipcode} = qq|<th><a class=listheading href=$href&sort=zipcode>|.$locale->text('Zip/Postal Code').qq|</a></th>|;
   $column_header{country} = qq|<th><a class=listheading href=$href&sort=country>|.$locale->text('Country').qq|</a></th>|;
-  $column_header{contact} = qq|<th><a class=listheading href=$href&sort=contact>|.$locale->text('Contact').qq|</a></th>|;
+  $column_header{salutation} = qq|<th>|.$locale->text('Salutation').qq|</th>|;
+  $column_header{lastname} = qq|<th>&nbsp;</th>|;
+  $column_header{firstname} = qq|<th><a class=listheading href=$href&sort=contact>|.$locale->text('Contact').qq|</a></th>|;
+  $column_header{contacttitle} = qq|<th>|.$locale->text('Title').qq|</th>|;
+  $column_header{gender} = qq|<th>|.$locale->text('G').qq|</th>|;
+  $column_header{occupation} = qq|<th><a class=listheading href=$href&sort=occupation>|.$locale->text('Occupation').qq|</a></th>|;
   $column_header{phone} = qq|<th><a class=listheading href=$href&sort=phone>|.$locale->text('Phone').qq|</a></th>|;
   $column_header{fax} = qq|<th><a class=listheading href=$href&sort=fax>|.$locale->text('Fax').qq|</a></th>|;
   $column_header{email} = qq|<th><a class=listheading href=$href&sort=email>|.$locale->text('E-mail').qq|</a></th>|;
   $column_header{cc} = qq|<th><a class=listheading href=$href&sort=cc>|.$locale->text('Cc').qq|</a></th>|;
-  $column_header{bcc} = qq|<th><a class=listheading href=$href&sort=cc>|.$locale->text('Bcc').qq|</a></th>|;
+  $column_header{bcc} = qq|<th><a class=listheading href=$href&sort=bcc>|.$locale->text('Bcc').qq|</a></th>|;
   $column_header{notes} = qq|<th><a class=listheading href=$href&sort=notes>|.$locale->text('Notes').qq|</a></th>|;
   $column_header{discount} = qq|<th class=listheading>%</th>|;
   $column_header{terms} = qq|<th class=listheading>|.$locale->text('Terms').qq|</th>|;
@@ -815,6 +840,8 @@ sub list_names {
   $column_header{gifi_accno} = qq|<th><a class=listheading href=$href&sort=gifi_accno>|.$locale->text('GIFI').qq|</a></th>|;
   $column_header{sic_code} = qq|<th><a class=listheading href=$href&sort=sic_code>|.$locale->text('SIC').qq|</a></th>|;
   $column_header{business} = qq|<th><a class=listheading href=$href&sort=business>|.$locale->text('Type of Business').qq|</a></th>|;
+
+  $column_header{bank} = qq|<th class=listheading>|.$locale->text('Bank').qq|</th>|;
   $column_header{iban} = qq|<th class=listheading>|.$locale->text('IBAN').qq|</th>|;
   $column_header{bic} = qq|<th class=listheading>|.$locale->text('BIC').qq|</th>|;
   $column_header{remittancevoucher} = qq|<th class=listheading>|.$locale->text('RV').qq|</th>|;
@@ -1026,16 +1053,16 @@ sub list_names {
   }
   
   $i = 1;
-  if ($myconfig{acs} !~ /AR--AR/) {
+  if ($myconfig{acs} !~ /Customers--/) {
     if ($form->{db} eq 'customer') {
-      $button{'AR--Customers--Add Customer'}{code} = qq|<input class=submit type=submit name=action value="|.$locale->text('Add Customer').qq|"> |;
-      $button{'AR--Customers--Add Customer'}{order} = $i++;
+      $button{'Customers--Add Customer'}{code} = qq|<input class=submit type=submit name=action value="|.$locale->text('Add Customer').qq|"> |;
+      $button{'Customers--Add Customer'}{order} = $i++;
     }
   }
-  if ($myconfig{acs} !~ /AP--AP/) {
+  if ($myconfig{acs} !~ /Vendors--/) {
     if ($form->{db} eq 'vendor') {
-      $button{'AP--Vendors--Add Vendor'}{code} = qq|<input class=submit type=submit name=action value="|.$locale->text('Add Vendor').qq|"> |;
-      $button{'AP--Vendors--Add Vendor'}{order} = $i++;
+      $button{'Vendors--Add Vendor'}{code} = qq|<input class=submit type=submit name=action value="|.$locale->text('Add Vendor').qq|"> |;
+      $button{'Vendors--Add Vendor'}{order} = $i++;
     }
   }
   
@@ -1595,8 +1622,9 @@ sub form_header {
 
 
   if ($form->{selectemployee}) {
+
     if ($myconfig{role} eq 'user') {
-      if ($form->{id}) {
+      if ($form->{id} && $form->{employee_id}) {
 	$form->{selectemployee} = "\n$form->{employee}";
       }
     }
@@ -1633,16 +1661,16 @@ sub form_header {
               <input type=hidden name=action value="update">
 	      <tr>
 	        <td align=center><b>|.$locale->text('Type').qq|</b>
-		<input name=typeofcontact type=radio value="company" $typeofcontact{company} onChange="javascript:document.forms[0].submit()">|.$locale->text('Company').qq|
-		<input name=typeofcontact type=radio value="person" $typeofcontact{person} onChange="javascript:document.forms[0].submit()">|.$locale->text('Person').qq|
+		<input name=typeofcontact type=radio value="company" $typeofcontact{company} onClick="javascript:document.forms[0].submit()">|.$locale->text('Company').qq|
+		<input name=typeofcontact type=radio value="person" $typeofcontact{person} onClick="javascript:document.forms[0].submit()">|.$locale->text('Person').qq|
 		</td>
 	      </tr>
 |;
    
 
+  for (qw(M F)) { $gender{$_} = "checked" if $form->{gender} eq $_ }
+  
   if ($form->{typeofcontact} eq 'person') {
- 
-    for (qw(M F)) { $gender{$_} = "checked" if $form->{gender} eq $_ }
       
     $name = qq|
 	      <tr>
@@ -1698,7 +1726,17 @@ sub form_header {
 		<th align=right nowrap>|.$locale->text('Title').qq|</th>
 		<td><input name=contacttitle size=32 maxlength=32 value="|.$form->quote($form->{contacttitle}).qq|"></td>
 	      </tr>
-|.$form->hide_form(qw(gender occupation));
+	      <tr>
+		<th align=right nowrap>|.$locale->text('Occupation').qq|</th>
+		<td><input name=occupation size=32 maxlength=32 value="|.$form->quote($form->{occupation}).qq|"></td>
+	      </tr>
+	      <tr>
+		<th align=right></th>
+		<td><input name=gender type=radio value="M" $gender{M}>|.$locale->text('Male').qq|
+		<input name=gender type=radio value="F" $gender{F}>|.$locale->text('Female').qq|
+		</td>
+	      </tr>
+|;
 
   } 
 
@@ -1928,6 +1966,7 @@ sub form_footer {
 	     'Purchase Order' => { ndx => 16, key => 'O', value => $locale->text('Purchase Order') },
 	     'RFQ' => { ndx => 17, key => 'Q', value => $locale->text('RFQ') },
 	     'Pricelist' => { ndx => 18, key => 'P', value => $locale->text('Pricelist') },
+	     'New Number' => { ndx => 19, key => 'M', value => $locale->text('New Number') },
 	     'Delete' => { ndx => 19, key => 'D', value => $locale->text('Delete') },
 	    );
   
@@ -1935,8 +1974,9 @@ sub form_footer {
   %a = ();
   
   if ($form->{db} eq 'customer') {
-    if ($myconfig{acs} !~ /AR--Customers--Add Customer/) {
+    if ($myconfig{acs} !~ /Customers--Add Customer/) {
       $a{'Save'} = 1;
+      $a{'New Number'} = 1;
       $a{'Shipping Address'} = 1;
       $a{'Update'} = 1;
 
@@ -1977,7 +2017,7 @@ sub form_footer {
   }
   
   if ($form->{db} eq 'vendor') {
-    if ($myconfig{acs} !~ /AP--Vendors--Add Vendor/) {
+    if ($myconfig{acs} !~ /Vendors--Add Vendor/) {
       $a{'Save'} = 1;
       $a{'Shipping Address'} = 1;
       $a{'Update'} = 1;
@@ -1994,7 +2034,7 @@ sub form_footer {
       if ($myconfig{acs} !~ /AP--Add Transaction/) {
 	$a{'AP Transaction'} = 1;
       }
-      if ($myconfig{acs} !~ /AP--Vendor Invoice/) {
+      if ($myconfig{acs} !~ /Vendor Invoice/) {
 	$a{'Vendor Invoice'} = 1;
       }
       if ($myconfig{acs} !~ /AP--Debit Invoice/) {
@@ -2047,9 +2087,25 @@ sub shipping_address {
   $form->{title} = $locale->text('Shipping Address');
 
   $form->{name} ||= "$form->{firstname} $form->{lastname}";
-  
+
+  CT->ship_to(\%myconfig, \%$form);
+
+  %shipto = (
+          address1 => { i => 2, label => $locale->text('Address') },
+	  address2 => { i => 3, label => '' },
+	  city => { i => 4, label => $locale->text('City') },
+	  state => { i => 5, label => $locale->text('State/Province') },
+	  zipcode => { i => 6, label => $locale->text('Zip/Postal Code') },
+	  country => { i => 7, label => $locale->text('Country') },
+	  contact => { i => 8, label => $locale->text('Contact') },
+	  phone => { i => 9, label => $locale->text('Phone') },
+	  fax => { i => 10, label => $locale->text('Fax') },
+	  email => { i => 11, label => $locale->text('E-mail') } );
+
   $form->header;
 
+  $vcname = $locale->text('Name');
+
   print qq|
 <body>
 
@@ -2064,70 +2120,122 @@ sub shipping_address {
     <td>
       <table width=100%>
 	<tr>
-	  <th class=listheading colspan=2>$form->{name}</th>
+	  <th class=listheading colspan=3>$form->{name}</th>
 	</tr>
 	<tr>
-	  <th align=right nowrap>|.$locale->text('Name').qq|</th>
+	  <td></td>
+	  <th align=right nowrap>$vcname</th>
 	  <td><input name=shiptoname size=32 maxlength=64 value="|.$form->quote($form->{shiptoname}).qq|"></td>
 	</tr>
 	<tr>
-	  <th align=right nowrap>|.$locale->text('Address').qq|</th>
+	  <td></td>
+	  <th align=right nowrap>$shipto{address1}{label}</th>
 	  <td><input name=shiptoaddress1 size=32 maxlength=32 value="|.$form->quote($form->{shiptoaddress1}).qq|"></td>
 	</tr>
 	<tr>
-	  <th></th>
+	  <td></td>
+	  <td></td>
 	  <td><input name=shiptoaddress2 size=32 maxlength=32 value="|.$form->quote($form->{shiptoaddress2}).qq|"></td>
 	</tr>
 	<tr>
-	  <th align=right nowrap>|.$locale->text('City').qq|</th>
+	  <td></td>
+	  <th align=right nowrap>$shipto{city}{label}</th>
 	  <td><input name=shiptocity size=32 maxlength=32 value="|.$form->quote($form->{shiptocity}).qq|"></td>
 	</tr>
 	<tr>
-	  <th align=right nowrap>|.$locale->text('State/Province').qq|</th>
+	  <td></td>
+	  <th align=right nowrap>$shipto{state}{label}</th>
 	  <td><input name=shiptostate size=32 maxlength=32 value="|.$form->quote($form->{shiptostate}).qq|"></td>
 	</tr>
 	<tr>
-	  <th align=right nowrap>|.$locale->text('Zip/Postal Code').qq|</th>
+	  <td></td>
+	  <th align=right nowrap>$shipto{zipcode}{label}</th>
 	  <td><input name=shiptozipcode size=11 maxlength=10 value="|.$form->quote($form->{shiptozipcode}).qq|"></td>
 	</tr>
 	<tr>
-	  <th align=right nowrap>|.$locale->text('Country').qq|</th>
+	  <td></td>
+	  <th align=right nowrap>$shipto{country}{label}</th>
 	  <td><input name=shiptocountry size=32 maxlength=32 value="|.$form->quote($form->{shiptocountry}).qq|"></td>
 	</tr>
 	<tr>
-	  <th align=right nowrap>|.$locale->text('Contact').qq|</th>
+	  <td></td>
+	  <th align=right nowrap>$shipto{contact}{label}</th>
 	  <td><input name=shiptocontact size=35 maxlength=64 value="|.$form->quote($form->{shiptocontact}).qq|"></td>
 	</tr>
 	<tr>
-	  <th align=right nowrap>|.$locale->text('Phone').qq|</th>
+	  <td></td>
+	  <th align=right nowrap>$shipto{phone}{label}</th>
 	  <td><input name=shiptophone size=22 maxlength=20 value="$form->{shiptophone}"></td>
 	</tr>
 	<tr>
-	  <th align=right nowrap>|.$locale->text('Fax').qq|</th>
+	  <td></td>
+	  <th align=right nowrap>$shipto{fax}{label}</th>
 	  <td><input name=shiptofax size=22 maxlength=20 value="$form->{shiptofax}"></td>
 	</tr>
 	<tr>
-	  <th align=right nowrap>|.$locale->text('E-mail').qq|</th>
+	  <td></td>
+	  <th align=right nowrap>$shipto{email}{label}</th>
 	  <td><input name=shiptoemail size=32 value="$form->{shiptoemail}"></td>
 	</tr>
+|;
+
+  $i = 1;
+  for $ref (@{ $form->{all_shipto} }) {
+
+    print qq|
+        <tr>
+	  <td></td>
+	  <td><hr noshade></td>
+	  <td><hr noshade></td>
+        </tr>
+
+	<tr>
+	  <td><input name="ndx_$i" type=checkbox class=checkbox>
+	  <th align=right nowrap>$vcname</th>
+	  <td>$ref->{shiptoname}</td>
+        </tr>
+|;
+
+    for (sort { $shipto{$a}{i} <=> $shipto{$b}{i} } keys %shipto) {
+      print qq|
+        <tr>
+	  <td></td>
+	  <th align=right nowrap>$shipto{$_}{label}</th>
+	  <td>$ref->{"shipto$_"}</td>
+        </tr>
+|;
+    }
+
+    for (keys %$ref) { $form->{"${_}_$i"} = $ref->{$_} }
+    $form->hide_form(map { "${_}_$i" } keys %$ref);
+
+    $i++;
+  }
+  $form->{shipto_rows} = $i - 1;
+
+  print qq|
       </table>
     </td>
   </tr>
-  <tr>
-    <td><hr size=3 noshade></td>
-  </tr>
 </table>
 |;
 
-  for (map { "shipto$_" } qw(name address1 address2 city state zipcode country contact phone fax email)) { delete $form->{$_} }
+  for (qw(name address1 address2 city state zipcode country contact phone fax email)) {
+    delete $form->{"shipto$_"};
+    $form->{flds} .= "$_ ";
+  }
+  chop $form->{flds};
 
-  $form->{nextsub} = "update";
+  $form->{nextsub} = "shipto_selected";
   $form->{action} = $form->{nextsub};
-
+  
   $form->hide_form;
   
   print qq|
-  <input type=submit class=submit name=action value="|.$locale->text('Continue').qq|">
+<hr size=3 noshade>
+
+<br>
+<input type=submit class=submit name=action value="|.$locale->text('Continue').qq|">
   
 </form>
 
@@ -2138,6 +2246,20 @@ sub shipping_address {
 }
 
 
+sub shipto_selected {
+
+  for $i (1 .. $form->{shipto_rows}) {
+    if ($form->{"ndx_$i"}) {
+      for (split / /, $form->{flds}) { $form->{"shipto$_"} = $form->{"shipto${_}_$i"} }
+      last;
+    }
+  }
+
+  &update;
+
+}
+
+
 sub pricelist {
 
   if ("$form->{name}$form->{lastname}$form->{firstname}" eq "") {
@@ -2483,8 +2605,7 @@ sub update {
 
     $form->{title} = ($form->{id}) ? 'Edit' : 'Add';
 
-    &form_header;
-    &form_footer;
+    &display_form;
 
     return;
     
@@ -2895,6 +3016,23 @@ sub delete {
 }
 
 
+sub new_number {
+
+  $form->{"$form->{db}number"} = $form->update_defaults(\%myconfig, "$form->{db}number");
+
+  &display_form;
+
+}
+
+
+sub display_form {
+
+  &form_header;
+  &form_footer;
+
+}
+
+
 sub continue { &{ $form->{nextsub} } };
 
 sub add_customer { &add };
